==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/compagnon/lang/compagnon_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compagnon?lang_cible=lb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Wëllkom @nom@!',
	'c_accueil_configurer_site' => 'Äre Site astellen',
	'c_accueil_configurer_site_texte' => 'Eng vun den éischte Saachen ass ärem Site e Numm ginn.
De Moment heescht en "@nom@". De Numm vum Site ass uewe op der Säit ugewisen.
Wann dir drop klickt kënnt dir de Numm änneren, an him och e Logo oder Slogan ginn.',
	'c_accueil_publication' => 'Verëffentlecht!',
	'c_accueil_publication_texte' => 'Fir eng Säit ze verëffentleche musst dir en Artikel bäiflécken.
Duerfir musst dir op mannst eng Rubrik bäiflécken. Dir kënnt dat am Menu "Editioun" maachen andeem dir op "Rubrike" klickt.',
	'c_accueil_texte' => 'Dir sidd elo am privaten Deel vu SPIP.',
	'c_accueil_texte_revenir' => 'Dës Säit weist déi rezent editorial Aktivitéit op ärem Site.
Dir kënnt op dës Säit zeréck andeem dir op d’Haus-Symbol, uewen ënnert ärem Numm, klickt.',
	'c_article_redaction' => 'Den Artikel ass an der Redaktioun',
	'c_article_redaction_redacteur' => 'Den Artikel ass an der Redaktioun',
	'c_article_redaction_redacteur_texte' => 'Fir ären Artikel den Administrateure vum Site an deenen anere Redakteren virzeschloën, ännert am Cadre lénks "an der Aarbecht" op "virgeschloën".',
	'c_article_redaction_texte' => 'Fir dësen Artikel um ëffentleche Site ze weisen, musst dir säi Status änneren.
Am Cadre lénks, ännert "an der Aarbecht" op "verëffentlecht".',
	'c_articles_creer' => 'Wéi kann ech en Artikel bäiflécken?',
	'c_articles_creer_texte' => 'Dir kënnt en Artikel nëmme bäiflécken wann et eng Rubrik op ärem Site gëtt.
Dir kënnt eng Rubrik bäiflécken iwwert de Menu "Editioun", dann "Rubriken".',
	'c_job' => 'Aarbechten déi nach bleiwen...',
	'c_job_texte' => 'Dëst ass d’Lëscht vun de Maintenance-Aarbechten déi SPIP maache muss. Déi Aarbechten ginn a regelméissegen Ofstänn oder punktuell fir gréisser Saache gemaach, z.B. e Mailing.',
	'c_rubrique_publier' => 'Maacht en Artikel',
	'c_rubrique_publier_texte' => 'Eng Rubrik ass op ärem Site nëmme siichtbar wann e verëffentlechten Inhalt dran ass, z.B. e verëffentlechten Artikel.
Fléckt also en Artikel bäi. Dir kënnt dat op dëser Säit maachen, ënnert der Beschreiwung vun der Rubrik.',
	'c_rubriques_creer' => 'Fléckt eng éischt Rubrik bäi!',
	'c_rubriques_creer_texte' => 'D’Rubrike sinn d’Basis-Struktur vum Site; a jidderenger Rubrik kënnt dir Artikele bäiflécken.
Fänkt mat enger éischter Rubrik un.',

	// E
	'explication_activer_compagnon' => 'De Compagnon setzt Kommentaren op verschidde Säite vum privaten Deel bäi fir bei der Benotzung vu SPIP ze hëllefen. Wëllt dir en aschalten?',
	'explication_reinitialiser_compagnon' => 'D’Messagen déi schonns vun engem Auteur gesinn goufen gi nët méi gewisen. Wëllt dir all d’Message nei starten?',

	// L
	'label_activer_compagnon' => 'De Compagnon schalten?',
	'label_reinitialiser_compagnon' => 'D’Message vum Compagnon nei starten?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Gutt!',
	'ok_jai_compris' => 'Ech hu verstan!',
	'ok_merci' => 'Merci',
	'ok_parfait' => 'Perfekt!',

	// R
	'reinitialisation' => 'Nei-Start',
	'reinitialisation_ok' => 'De Nei-Start gouf gemach.',
	'reinitialiser' => 'Nei-Starten',
	'reinitialiser_moi' => 'Jo, nëmmen déi déi ech schonns gesinn hun',
	'reinitialiser_tous' => 'Jo, egal wéi en Auteur',

	// T
	'titre_compagnon' => 'De Compagnon',
	'titre_page_configurer_compagnon' => 'De Compagnon astellen'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/compagnon/lang/compagnon_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compagnon?lang_cible=lb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Wëllkom @nom@!',
	'c_accueil_configurer_site' => 'Äre Site astellen',
	'c_accueil_configurer_site_texte' => 'Eng vun den éischte Saachen ass ärem Site e Numm ginn.
De Moment heescht en "@nom@". De Numm vum Site ass uewe op der Säit ugewisen.
Wann dir drop klickt kënnt dir de Numm änneren, an him och e Logo oder Slogan ginn.',
	'c_accueil_publication' => 'Verëffentlecht!',
	'c_accueil_publication_texte' => 'Fir eng Säit ze verëffentleche musst dir en Artikel bäiflécken.
Duerfir musst dir op mannst eng Rubrik bäiflécken. Dir kënnt dat am Menu "Editioun" maachen andeem dir op "Rubrike" klickt.',
	'c_accueil_texte' => 'Dir sidd elo am privaten Deel vu SPIP.',
	'c_accueil_texte_revenir' => 'Dës Säit weist déi rezent editorial Aktivitéit op ärem Site.
Dir kënnt op dës Säit zeréck andeem dir op d’Haus-Symbol, uewen ënnert ärem Numm, klickt.', # MODIF
	'c_article_redaction' => 'Den Artikel ass an der Redaktioun',
	'c_article_redaction_redacteur' => 'Den Artikel ass an der Redaktioun',
	'c_article_redaction_redacteur_texte' => 'Fir ären Artikel den Administrateure vum Site an deenen anere Redakteren virzeschloën, ännert am Cadre lénks "an der Aarbecht" op "virgeschloën".',
	'c_article_redaction_texte' => 'Fir dësen Artikel um ëffentleche Site ze weisen, musst dir säi Status änneren.
Am Cadre lénks, ännert "an der Aarbecht" op "verëffentlecht".',
	'c_articles_creer' => 'Wéi kann ech en Artikel bäiflécken?',
	'c_articles_creer_texte' => 'Dir kënnt en Artikel nëmme bäiflécken wann et eng Rubrik op ärem Site gëtt.
Dir kënnt eng Rubrik bäiflécken iwwert de Menu "Editioun", dann "Rubriken".',
	'c_job' => 'Aarbechten déi nach bleiwen...',
	'c_job_texte' => 'Dëst ass d’Lëscht vun de Maintenance-Aarbechten déi SPIP maache muss. Déi Aarbechten ginn a regelméissegen Ofstänn oder punktuell fir gréisser Saache gemaach, z.B. e Mailing.',
	'c_rubrique_publier' => 'Maacht en Artikel',
	'c_rubrique_publier_texte' => 'Eng Rubrik ass op ärem Site nëmme siichtbar wann e verëffentlechten Inhalt dran ass, z.B. e verëffentlechten Artikel.
Fléckt also en Artikel bäi. Dir kënnt dat op dëser Säit maachen, ënnert der Beschreiwung vun der Rubrik.',
	'c_rubriques_creer' => 'Fléckt eng éischt Rubrik bäi!',
	'c_rubriques_creer_texte' => 'D’Rubrike sinn d’Basis-Struktur vum Site; a jidderenger Rubrik kënnt dir Artikele bäiflécken.
Fänkt mat enger éischter Rubrik un.',

	// E
	'explication_activer_compagnon' => 'De Compagnon setzt Kommentaren op verschidde Säite vum privaten Deel bäi fir bei der Benotzung vu SPIP ze hëllefen. Wëllt dir en aschalten?',
	'explication_reinitialiser_compagnon' => 'D’Messagen déi schonns vun engem Auteur gesinn goufen gi nët méi gewisen. Wëllt dir all d’Message nei starten?',

	// L
	'label_activer_compagnon' => 'De Compagnon schalten?',
	'label_reinitialiser_compagnon' => 'D’Message vum Compagnon nei starten?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Gutt!',
	'ok_jai_compris' => 'Ech hu verstan!',
	'ok_merci' => 'Merci',
	'ok_parfait' => 'Perfekt!',

	// R
	'reinitialisation' => 'Nei-Start',
	'reinitialisation_ok' => 'De Nei-Start gouf gemach.',
	'reinitialiser' => 'Nei-Starten',
	'reinitialiser_moi' => 'Jo, nëmmen déi déi ech schonns gesinn hun',
	'reinitialiser_tous' => 'Jo, egal wéi en Auteur',

	// T
	'titre_compagnon' => 'De Compagnon',
	'titre_page_configurer_compagnon' => 'De Compagnon astellen'
);

?>
